@@ -3,7 +3,7 @@ use warnings;
 
 use Blockchain::Ethereum::ABI::Encoder;
 use Blockchain::Ethereum::Transaction::EIP1559;
-use Blockchain::Ethereum::Keystore::Key;
+use Blockchain::Ethereum::Key;
 
 my $encoder = Blockchain::Ethereum::ABI::Encoder->new;
 $encoder->function('transfer')->append('address' => '0x9d8A62f656a8d1615C1294fd71e9CFb3E4855A4F')->append('uint256' => '1000');
@@ -19,7 +19,7 @@ my $transaction = Blockchain::Ethereum::Transaction::EIP1559->new(
     chain_id                 => '0x1'
 );
 
-my $key = Blockchain::Ethereum::Keystore::Key->new(
+my $key = Blockchain::Ethereum::Key->new(
     private_key => pack "H*",
     '4646464646464646464646464646464646464646464646464646464646464646'
 );
